@@ -2,6 +2,7 @@ import cv2
 import numpy as np
 from jcopvision.draw._cm import idx2color
 from jcopvision.utils import denorm_point
+from jcopvision.utils._denorm import denorm_pixel
 
 
 def draw_bbox(frame, pt1, pt2, color, label=None, conf=None, thickness=1, font=cv2.FONT_HERSHEY_SIMPLEX, fontsize=0.5,
@@ -53,7 +54,7 @@ def draw_bbox(frame, pt1, pt2, color, label=None, conf=None, thickness=1, font=c
     '''
     frame = frame.copy()
     if frame.dtype == np.float32:
-        frame = (frame * 255).astype(np.uint8)
+        frame = denorm_pixel(frame)
 
     if isinstance(color, int):
         color = idx2color(color)
