@@ -2,6 +2,7 @@ import cv2
 import numpy as np
 from jcopvision.draw._cm import idx2color
 from jcopvision.utils import denorm_point
+from jcopvision.utils._denorm import denorm_pixel
 
 
 def draw_circle(frame, pt, radius, color, thickness=1, is_normalized=True):
@@ -33,7 +34,7 @@ def draw_circle(frame, pt, radius, color, thickness=1, is_normalized=True):
     '''
     frame = frame.copy()
     if frame.dtype == np.float32:
-        frame = (frame * 255).astype(np.uint8)
+        frame = denorm_pixel(frame)
 
     if isinstance(color, int):
         color = idx2color(color)
