@@ -39,3 +39,7 @@ def denorm_landmark(frame, box, points, to_int=True):
     points = points * [x2 - x1, y2 - y1] + [x1, y1]
     points = denorm_point(frame, points, to_int)
     return points
+
+
+def denorm_pixel(frame):
+    return (frame * 255).astype(np.uint8)
